aboutsummaryrefslogtreecommitdiff
path: root/lib/utils_base.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/utils_base.h')
-rw-r--r--lib/utils_base.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/utils_base.h b/lib/utils_base.h
index 0cb371fd..3b00da57 100644
--- a/lib/utils_base.h
+++ b/lib/utils_base.h
@@ -1,6 +1,6 @@
#ifndef _UTILS_BASE_
#define _UTILS_BASE_
/* Header file for nagios plugins utils_base.c */
#include "sha1.h"
@@ -52,7 +52,7 @@ typedef struct np_struct {
state_key *state;
int argc;
char **argv;
- } nagios_plugin;
+ } monitoring_plugin;
range *parse_range_string (char *);
int _set_thresholds(thresholds **, char *, char *);
@@ -1,6 +1,6 @@
#ifndef _UTILS_BASE_
#define _UTILS_BASE_
-/* Header file for nagios plugins utils_base.c */
+/* Header file for monitoring plugins utils_base.c */
#include "sha1.h"